# Environment variables for the pmproxy daemon.  Refer also to
# the pmproxy.options file for additional configuration state.

# Behaviour regarding listening on external-facing interfaces;
# unset PMPROXY_LOCAL to allow connections from remote hosts.
# A value of 0 permits remote connections, 1 permits local only.
PMPROXY_LOCAL={{ pcp_pmproxy_localonly }}

# Max length to which the queue of pending connections may grow
# A value of 5 is the default.
# PMPROXY_MAXPENDING=5
