#
# PCP bpftrace PMDA config file - see pmdabpftrace(1) and PMDA(3)
#

[bpftrace]
# Path to bpftrace executable
bpftrace_path = bpftrace

# Unnamed scripts are removed if their value is not requested within a
# specified time period (in seconds)
script_expiry_time = 60

# Maximum throughput of bpftrace scripts in bytes
max_throughput = 2097152


[dynamic_scripts]
# Control whether the bpftrace PMDA should start bpftrace scripts
# on demand by executing pmStore (3) bpftrace.control.register
# required for the PCP bpftrace datasource in grafana-pcp
enabled = true

# See https://grafana-pcp.readthedocs.io/en/latest/datasources/authentication.html
# on how to set up authentication. Disabling authentication is NOT RECOMMENDED,
# as everyone would be able to run bpftrace scripts AS ROOT, which can leak sensitive
# information and run unsafe commands!
auth_enabled = true

# Comma-separated list of usernames which are allowed to register
# bpftrace scripts
allowed_users = {{ __bpftrace_usernames }}
